@@ -4,13 +4,13 @@ OC.L10N.register(
     "Please provide a content for your comment." : "Zadejte obsah svého komentáře.",
     "Posting the comment failed." : "Odeslání komentáře se nezdařilo.",
     "The comment has been deleted" : "Komentář byl smazán",
-    "The associated stack is deleted as well, it will be restored as well." : "Související stack je také smazaný a bude také obnoven.",
-    "Restore associated stack" : "Obnovit související stack",
+    "The associated stack is deleted as well, it will be restored as well." : "Související sloupec je také smazaný a bude také obnoven.",
+    "Restore associated stack" : "Obnovit související sloupec",
     "Remove user from card" : "Odebrat uživatele z karty",
     "Hours" : "Hodiny",
     "Minutes" : "Minuty",
     "Link to a board" : "Propojit s tabulí",
-    "Maximum file size of {size} exceeded" : "U souboru {size} překročena nejvyšší umožněná velikost",
+    "Maximum file size of {size} exceeded" : "Překročena nejvyšší umožněná velikost souboru {size}",
     "File already exists" : "Soubor už existuje",
     "You have created a new board {board}" : "Vytvořili jste tabuli {board}",
     "{user} has created a new board {board}" : "{user} vytvořil(a) novou tabuli {board}",
@@ -28,55 +28,55 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} zaarchivoval(a) tabuli {before}",
     "You have unarchived the board {board}" : "Vrátili jste zpět z archivace tabuli {board}",
     "{user} has unarchived the board {before}" : "{user} vrátil(a) tabuli {before} zpět z archivace",
-    "You have created a new stack {stack} on board {board}" : "Vytvořili jste novou hromádku {stack} na tabuli {board}",
-    "{user} has created a new stack {stack} on board {board}" : "{user} vytvořil(a) nový balíček {stack} na tabuli {board}",
-    "You have renamed stack {before} to {stack} on board {board}" : "Přejmenovali jste hromádku {before} na {stack} na desce {board}",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "{user} přejmenoval(a) hromádku {before} na {stack} na desce {board}",
-    "You have deleted stack {stack} on board {board}" : "Smazali jste balíček {stack} na desce {board}",
-    "{user} has deleted stack {stack} on board {board}" : "{user} smazal(a) balíček {stack} na desce {board}",
-    "You have created card {card} in stack {stack} on board {board}" : "Vytvořili jste kartu {card} v balíčku {stack} na kartě {board}",
+    "You have created a new stack {stack} on board {board}" : "Vytvořili jste nový sloupec {stack} na tabuli {board}",
+    "{user} has created a new stack {stack} on board {board}" : "{user} vytvořil(a) nový sloupec {stack} na tabuli {board}",
+    "You have renamed stack {before} to {stack} on board {board}" : "Přejmenovali jste sloupec {before} na {stack} na tabuli {board}",
+    "{user} has renamed stack {before} to {stack} on board {board}" : "{user} přejmenoval(a) sloupec {before} na {stack} na tabuli {board}",
+    "You have deleted stack {stack} on board {board}" : "Smazali jste sloupec {stack} na tabuli {board}",
+    "{user} has deleted stack {stack} on board {board}" : "{user} smazal(a) sloupec {stack} na tabuli {board}",
+    "You have created card {card} in stack {stack} on board {board}" : "Vytvořili jste kartu {card} ve sloupci {stack} na tabuli {board}",
     "{user} has created card {card} in stack {stack} on board {board}" : "{user} vytvořil(a) kartu {card} ve sloupci {stack} na tabuli {board}",
-    "You have deleted card {card} in stack {stack} on board {board}" : "Smazali jste kartu {card} na hromádce {stack} na desce {board}",
-    "{user} has deleted card {card} in stack {stack} on board {board}" : "{user} smazal(a) kartu {card} v balíčku {board} na desce {board}",
+    "You have deleted card {card} in stack {stack} on board {board}" : "Smazali jste kartu {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has deleted card {card} in stack {stack} on board {board}" : "{user} smazal(a) kartu {card} ve sloupci {board} na tabuli {board}",
     "You have renamed the card {before} to {card}" : "Přejmenovali jste kartu {before} na {card}",
     "{user} has renamed the card {before} to {card}" : "{user} přejmenoval(a) {before} na {card}",
-    "You have added a description to card {card} in stack {stack} on board {board}" : "Přidali jste popis ke kartě {card} v hromádce {stack} na tabuli {board}",
-    "{user} has added a description to card {card} in stack {stack} on board {board}" : "{user} přidal(a) popis ke kartě {card} v hromádce {stack} na tabuli {board}",
-    "You have updated the description of card {card} in stack {stack} on board {board}" : "Aktualizovali jste popis karty {card} v hromádce {stack} na desce {board}",
-    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "{user} aktualizoval(a) popis karty {card} na hromádce {stack} na nástěnce {board}",
-    "You have archived card {card} in stack {stack} on board {board}" : "Zaarchivovali kartu {card} v balíčku {stack} na tabuli {board}",
-    "{user} has archived card {card} in stack {stack} on board {board}" : "{user} zaarchivoval(a) kartu {card} v balíčku {stack} na desce {board}",
-    "You have unarchived card {card} in stack {stack} on board {board}" : "Zrušili jste archivaci karty {card} na hromádce {stack} na desce {board}",
-    "{user} has unarchived card {card} in stack {stack} on board {board}" : "{user} zrušil(a) archivaci karty {card} na hromádce {stack} na tabuli {board}",
-    "You have removed the due date of card {card}" : "Odebrali jste termín karty {card}",
-    "{user} has removed the due date of card {card}" : "{user} odebral(a) termín karty {card}",
-    "You have set the due date of card {card} to {after}" : "Nastavili jste termín na kartě {card} na {after}",
-    "{user} has set the due date of card {card} to {after}" : "{user} nastavil(a) termín karty {card} na {after}",
-    "You have updated the due date of card {card} to {after}" : "Změnili jste termín na kartě {card} na {after}",
-    "{user} has updated the due date of card {card} to {after}" : "{user} aktualizoval termín karty {card} na {after}",
-    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Přidali jste štítek {label} kartě {card} v hromádce {stack} na nástěnce {board}",
-    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "{user} přidal(a) štítek {label} ke kartě {card} v hromádce {stack} na nástěnce {board}",
-    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Odebrali jste štítek {label} z karty {card} v hromádce {stack} na desce {board}",
-    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "{user} odebral(a) štítek {label} z karty {card} na hromádce {stack} na tabuli {board}",
+    "You have added a description to card {card} in stack {stack} on board {board}" : "Přidali jste popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has added a description to card {card} in stack {stack} on board {board}" : "{user} přidal(a) popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
+    "You have updated the description of card {card} in stack {stack} on board {board}" : "Aktualizovali jste popis karty {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "{user} aktualizoval(a) popis karty {card} ve sloupci {stack} na tabuli {board}",
+    "You have archived card {card} in stack {stack} on board {board}" : "Zaarchivovali kartu {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has archived card {card} in stack {stack} on board {board}" : "{user} zaarchivoval(a) kartu {card} ve sloupci {stack} na tabuli {board}",
+    "You have unarchived card {card} in stack {stack} on board {board}" : "Zrušili jste archivaci karty {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has unarchived card {card} in stack {stack} on board {board}" : "{user} zrušil(a) archivaci karty {card} ve sloupci {stack} na tabuli {board}",
+    "You have removed the due date of card {card}" : "Odebrali jste termín u karty {card}",
+    "{user} has removed the due date of card {card}" : "{user} odebral(a) termín u karty {card}",
+    "You have set the due date of card {card} to {after}" : "Nastavili jste termín u karty {card} na {after}",
+    "{user} has set the due date of card {card} to {after}" : "{user} nastavil(a) termín u karty {card} na {after}",
+    "You have updated the due date of card {card} to {after}" : "Změnili jste termín u karty {card} na {after}",
+    "{user} has updated the due date of card {card} to {after}" : "{user} aktualizoval(a) termín u karty {card} na {after}",
+    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Přidali jste štítek {label} kartě {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "{user} přidal(a) štítek {label} ke kartě {card} ve sloupci {stack} na tabuli {board}",
+    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Odebrali jste štítek {label} z karty {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "{user} odebral(a) štítek {label} z karty {card} ve sloupci {stack} na tabuli {board}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Přiřadili jste {assigneduser} ke kartě {card} na tabuli {board}",
-    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} přiřadil(a) {assigneduser} ke kartě {card} na desce {board}",
-    "You have unassigned {assigneduser} from card {card} on board {board}" : "Zrušili jste přiřazení {assigneduser} u karty {card} na nástěnce {board}",
-    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} zrušil(a) přiřazení {assigneduser} z karty {card} na desce {board}",
-    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Přesunuli jste kartu {card} z balíčku {stackBefore} do {stack}",
-    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "{user} přesunul(a) kartu {card} z balíčku {stackBefore} do {stack}",
+    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} přiřadil(a) {assigneduser} ke kartě {card} na tabuli {board}",
+    "You have unassigned {assigneduser} from card {card} on board {board}" : "Zrušili jste přiřazení {assigneduser} u karty {card} na tabuli {board}",
+    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} zrušil(a) přiřazení {assigneduser} z karty {card} na tabuli {board}",
+    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Přesunuli jste kartu {card} ze sloupce {stackBefore} do {stack}",
+    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "{user} přesunul(a) kartu {card} ze sloupce {stackBefore} do {stack}",
     "You have added the attachment {attachment} to card {card}" : "Přidali jste přílohu {attachment} ke kartě {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} přidal(a) přílohu {attachment} ke kartě {card}",
-    "You have updated the attachment {attachment} on card {card}" : "Aktualizovali jste přílohu {attachment} na kartě {card}",
-    "{user} has updated the attachment {attachment} on card {card}" : "{user} aktualizoval(a) přílohu {attachment} na kartě {card}",
+    "You have updated the attachment {attachment} on card {card}" : "Aktualizovali jste přílohu {attachment} u karty {card}",
+    "{user} has updated the attachment {attachment} on card {card}" : "{user} aktualizoval(a) přílohu {attachment} u karty {card}",
     "You have deleted the attachment {attachment} from card {card}" : "Smazali jste přílohu {attachment} u karty {card}",
-    "{user} has deleted the attachment {attachment} from card {card}" : "{user} smazal(a) přílohu {attachment} na kartě {card}",
+    "{user} has deleted the attachment {attachment} from card {card}" : "{user} smazal(a) přílohu {attachment} u karty {card}",
     "You have restored the attachment {attachment} to card {card}" : "Obnovili jste přílohu {attachment} ke kartě {card}",
     "{user} has restored the attachment {attachment} to card {card}" : "{user} obnovil(a) přílohu {attachment} ke kartě {card}",
     "You have commented on card {card}" : "Přidali jste komentář na kartě {card}",
     "{user} has commented on card {card}" : "{user} přidal(a) komentář na kartě {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Popis karty</strong> v Deck-aplikace byl změněn",
-    "Deck" : "Balík",
-    "Changes in the <strong>Deck app</strong>" : "Změny v <strong>Deck aplikace</strong>",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Popis karty</strong> v aplikaci Deck byl změněn",
+    "Deck" : "Deck",
+    "Changes in the <strong>Deck app</strong>" : "Změny v <strong>aplikaci Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Na kartě byl vytvořen <strong>komentář</strong>",
     "Personal" : "Osobní",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kartu „%s“ na „%s“ vám přiřadil(a) %s.",
@@ -107,10 +107,10 @@ OC.L10N.register(
     "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru.",
     "No file uploaded or file size exceeds maximum of %s" : "Nebyl nahrán žádný soubor nebo jeho velikost přesáhla %s",
     "A kanban style project and personal management tool for Nextcloud" : "Nástroj pro projektový a osobní řízení ve stylu Kanban.",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Karty jsou nástroj zacílený na osobní nebo projektové plánování týmů v Kanban stylu, vestavěný v Nextcloud.\n\n\n- 📥 Zadávejte a uspořádávejte své úkoly do karet\n- 📄 Zapisujte si dodatečné poznámky \n- 🔖 Přiřazujte štítky pro ještě lepší organizaci\n- 👥 Sdílejte se svým týmem, přáteli nebo rodinou\n- 🚀 Dostaňte svůj projekt pod kontrolu",
-    "Select the board to link to a project" : "Vyberte nástěnku kterou propojit s projektem",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je nástroj cílený na osobní nebo projektové plánování týmů v Kanban stylu, vestavěný v Nextcloud.\n\n\n- 📥 Zadávejte a uspořádávejte své úkoly do karet\n- 📄 Zapisujte si dodatečné poznámky \n- 🔖 Přiřazujte štítky pro ještě lepší organizaci\n- 👥 Sdílejte se svým týmem, přáteli nebo rodinou\n- 🚀 Dostaňte svůj projekt pod kontrolu",
+    "Select the board to link to a project" : "Vyberte tabuli kterou propojit s projektem",
     "Select board" : "Vybrat tabuli",
-    "Add a new stack" : "Přidat nový zásobník",
+    "Add a new stack" : "Přidat nový sloupec",
     "Submit" : "Odeslat",
     "Show archived cards" : "Zobrazit archivované karty",
     "Hide archived cards" : "Skrýt archivované karty",
@@ -131,7 +131,7 @@ OC.L10N.register(
     "Add card" : "Přidat kartu",
     "Close" : "Zavřít",
     "Sharing" : "Sdílení",
-    "Tags" : "Značky",
+    "Tags" : "Štítky",
     "Deleted items" : "Smazané položky",
     "Timeline" : "Časová osa",
     "Select users or groups to share with" : "Vyberte uživatele nebo skupiny pro sdílení",
@@ -149,20 +149,20 @@ OC.L10N.register(
     "Delete tag" : "Smazat štítek",
     "Create" : "Vytvořit",
     "Create a new tag" : "Vytvořit nový štítek",
-    "Deleted stacks" : "Smazané zásobníky",
+    "Deleted stacks" : "Smazané sloupce",
     "Deleted cards" : "Smazané karty",
     "Status" : "Stav",
-    "No archived boards to display" : "Žádné archivované nástěnky k zobrazení",
-    "No shared boards to display" : "Žádné sdílené nástěnky k zobrazení",
+    "No archived boards to display" : "Žádné archivované tabule k zobrazení",
+    "No shared boards to display" : "Žádné sdílené tabule k zobrazení",
     "Title" : "Název",
     "Members" : "Členové",
     "More actions" : "Více akcí",
     "Edit board" : "Upravit tabuli",
-    "Archive board" : "Archivovaná tabule",
+    "Archive board" : "Archivovat tabuli",
     "Unarchive board" : "Vrátit tabuli zpět z archivu",
     "Delete board" : "Smazat tabuli",
     "Update board" : "Aktualizovat tabuli",
-    "Reset board" : "Vrátit tabuli do výchozího stavu",
+    "Reset board" : "Vrátit tabuli do předchozího stavu",
     "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Vrátit smazání tabule – jinak bude nadobro odstraněna během příštího spuštění naplánovaných úloh.",
     "Create new board" : "Vytvořit novou tabuli",
     "New board title" : "Název nové tabule",
@@ -176,14 +176,14 @@ OC.L10N.register(
     "Delete attachment" : "Smazat přílohu",
     "Modified:" : "Změněno:",
     "Created:" : "Vytvořeno:",
-    "Choose a tag" : "Vyberte štítek",
+    "Choose a tag" : "Zvolte štítek",
     "Add a tag" : "Přidat štítek",
     "Select tags" : "Výběr štítků",
     "Assign users" : "Přiřadit uživatele",
     "Choose a user to assign" : "Zvolte uživatele kterého přiřadit",
-    "Assign this card to a user" : "Přiřadit kartu uživateli",
+    "Assign this card to a user" : "Přiřadit tuto kartu uživateli",
     "Due date" : "Termín",
-    "Click to set" : "Klikněte pro výběr",
+    "Click to set" : "Klikn. vyberte",
     "Remove due date" : "Odstranit termín",
     "Description" : "Popis",
     "Attachments" : "Přílohy",
@@ -192,12 +192,12 @@ OC.L10N.register(
     "Insert attachment" : "Vložit přílohu",
     "Formatting help" : "Nápověda k formátování",
     "Upload attachment" : "Nahrát přílohu",
-    "Add a card description…" : "Přidat popis karty…",
+    "Add a card description…" : "Přidejte popis karty…",
     "Shared boards" : "Sdílené tabule",
     "Move board to archive" : "Přesunout tabuli do archivu",
     "Create a new board" : "Vytvořit novou tabuli",
     "Settings" : "Nastavení",
     "Limit deck to groups" : "Omezit Deck na skupiny",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení Decků brání uživatelům, kteří nejsou součástí těchto skupin, při vytváření vlastních tabulí. Uživatelé mohou stále pracovat na tabulích, které jsou s nimi sdíleny."
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
